/**
 * (C) Copyright IBM Corp. 2023.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * Given two Error instances 'error' and 'causedBy', this function will
 * update 'error' by chaining 'causedBy' to it.
 * Specifically, 'causedBy''s message and stack will be appended
 * to 'error''s message and stack, respectively, to simulate chained Errors.
 *
 * @param error the Error object to be updated
 * @param causedBy an Error object that represents the cause of 'error'
 * @returns 'error' after updating its message and stack fields
 */
export function chainError(error, causedBy) {
    error.message += ` ${causedBy.toString()}`;
    if (causedBy.stack) {
        error.stack += `\nCaused by: ${causedBy.stack}`;
    }
    return error;
}
